CropMetadata class
Metadata for mapping landmark coordinates from crop space back to original image space.
Constructors
- CropMetadata({required double cx1, required double cy1, required double cropW, required double cropH})
-
Creates crop metadata with origin and dimensions.
const
Properties
- cropH → double
-
Height of the crop region in original image pixels.
final
- cropW → double
-
Width of the crop region in original image pixels.
final
- cx1 → double
-
Left edge of the crop region in original image pixels.
final
- cy1 → double
-
Top edge of the crop region in original image pixels.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited